@@ -1,4 +1,4 @@
 NormalCF <- function (p, B) {
   ## Liptak combining function
-  -sum(qnorm(open01(p, B)))
+  -sum(stats::qnorm(open01(p, B)))
 }
